@@ -2609,7 +2609,7 @@ mjit::Compiler::jsop_stricteq(JSOp op)
     if (other->isConstant()) {
         masm.set32(cond, testReg, Imm32(other->getValue().toInt32()), resultReg);
     } else if (frame.shouldAvoidDataRemat(other)) {
-        masm.set32(cond, testReg, frame.addressOf(other), resultReg);
+        masm.set32(cond, testReg, masm.payloadOf(frame.addressOf(other)), resultReg);
     } else {
         RegisterID otherReg = frame.tempRegForData(other);
 
